==> heyu_1.19.orig.tar.gz: heyu-1.19.orig/message.c <==

/*
 * Copyright 1986 by Larry Campbell, 73 Concord Street, Maynard MA 01754 USA
 * (maynard!campbell).  You may freely copy, use, and distribute this software
 * subject to the following restrictions:
 *
 *  1)	You may not charge money for it.
 *  2)	You may not remove or alter this copyright notice.
 *  3)	You may not claim you wrote it.
 *  4)	If you make improvements (or other changes), you are requested
 *	to send them to me, so there's a focal point for distributing
 *	improved versions.
 *
 * John Chmielewski (tesla!jlc until 9/1/86, then rogue!jlc) assisted
 * by doing the System V port and adding some nice features.  Thanks!
 */

#include <stdio.h>
#include "x10.h"

char *E_2MANY = EM_2MANY;
char *E_INVCN = EM_INVCN;
char *E_WNA = EM_WNA;
char *E_NMA = EM_NMA;
char *E_NOCMD = EM_NOCMD;

void exit();

usage(s)
char *s;
{

    char RCSID[]= "@(#) $Id: message.c,v 1.6 1998/04/28 04:06:53 dbs Exp $\n";

/*
 * Don't combine the two calls to fputs or my compiler will
 * gag with "token too long"
 */

    if( s != NULL )
    (void) fprintf(stderr, "Command error: %s\n", s);
    (void) fputs("Usage:\n\
 heyu date                    returns date in date(1) input format\n", stderr);
    (void) fputs("\
 heyu erase                   Zeroes EEPROM, eraseing all events and macros\n\
 heyu help                    prints this message and exits\n\
 heyu info                    gets current settings\n\
 heyu monitor                 monitor X10 activity (end with <BREAK>)\n\
 heyu reset  [housecode]      reset interface to 'A' or specified housecode\n\
 heyu setclock                sets X10 clock to system clock\n\
 heyu status ann[,nn...]      returns status of smart modules (rr501...)\n\
 heyu stop                    stops the current relay daemon\n\
 heyu turn ann[,nn...] on|off|dim|bright [vv]\n\
                              changes state of housecode a, unit nn by vv\n\
 heyu version                 prints the version and exits\n\
", stderr);
    (void) fputs("Verbose mode is enabled if the first parameter is -v\n",
            stderr);
    exit(1);
}

error(s)
char *s;
{
    (void) fprintf(stderr, "HEYU: %s\n", s);
    quit();
}

==> heyu_1.28-3.tar.gz: heyu-1.28/message.c <==
/*
 * Copyright 1986 by Larry Campbell, 73 Concord Street, Maynard MA 01754 USA
 * (maynard!campbell).  You may freely copy, use, and distribute this software
 * subject to the following restrictions:
 *
 *  1)	You may not charge money for it.
 *  2)	You may not remove or alter this copyright notice.
 *  3)	You may not claim you wrote it.
 *  4)	If you make improvements (or other changes), you are requested
 *	to send them to me, so there's a focal point for distributing
 *	improved versions.
 *
 * John Chmielewski (tesla!jlc until 9/1/86, then rogue!jlc) assisted
 * by doing the System V port and adding some nice features.  Thanks!
 */
/*
 * updated by Daniel Suthers, dbs@tanj.com 1996 -- 2000 
 */

#include <stdio.h>
#include "x10.h"

char *E_2MANY = EM_2MANY;
char *E_INVCN = EM_INVCN;
char *E_WNA = EM_WNA;
char *E_NMA = EM_NMA;
char *E_NOCMD = EM_NOCMD;

void exit();

int usage(s)
char *s;
{

    char RCSID[]= "@(#) $Id: message.c,v 1.12 1999/12/26 20:37:17 dbs Exp dbs $\n";

/*
 * Don't combine the two calls to fputs or my compiler will
 * gag with "token too long"
 */

    display(RCSID);

    if( s != NULL )
    (void) fprintf(stderr, "Command error: %s\n", s);
    (void) fputs("Usage:\n\
 heyu date                    returns date in date(1) input format\n", stderr);
    (void) fputs("\
 heyu erase                   Zeroes EEPROM, eraseing all events and macros\n\
 heyu help                    prints this message and exits\n\
 heyu info                    gets current settings\n\
 heyu monitor                 monitor X10 activity (end with <BREAK>)\n\
 heyu preset ann vv           sets unit to level vv for next dim/bright\n\
 heyu reset  [housecode]      reset interface to 'A' or specified housecode\n\
 heyu setclock                sets X10 clock to system clock\n\
 heyu status ann[,nn...]      returns status of smart modules (rr501...)\n\
 heyu stop                    stops the current relay daemon\n\
 heyu turn ann[,nn...] on|off|dim|bright [vv]\n\
                              changes state of housecode a, unit nn by vv\n\
 heyu upload [check]          Uploads schedule to CM11a or checks the file\n\
 heyu version                 prints the version and exits\n\
", stderr);
    (void) fputs("Verbose mode is enabled if the first parameter is -v\n",
            stderr);
    exit(1);
}

void error(s)
char *s;
{
    extern void quit();

    (void) fprintf(stderr, "HEYU: %s\n", s);
    quit();
}
